@@ -1,6 +1,6 @@
 package Games::Cards::Pair::Params;
 
-$Games::Cards::Pair::Params::VERSION = '0.10';
+$Games::Cards::Pair::Params::VERSION = '0.11';
 
 =head1 NAME
 
@@ -8,7 +8,7 @@ Games::Cards::Pair::Params - Placeholder for parameters for Games::Cards::Pair.
 
 =head1 VERSION
 
-Version 0.10
+Version 0.11
 
 =cut
 
@@ -22,13 +22,13 @@ require Exporter;
 @ISA = qw(Exporter);
 @EXPORT_OK = qw($Suit $Value $ZeroOrOne $Num);
 
-my $SUITS =     { 'Clubs' => 1, 'Diamonds' => 1, 'Hearts' => 1, 'Spades' => 1 };
+my $SUITS =     { 'C' => 1, 'D' => 1, 'H' => 1, 'S' => 1 };
 our $Suit = sub { die "ERROR: Invalid data type 'suit' [$_[0]]" unless check_suit($_[0]); };
 sub check_suit  { return exists $SUITS->{ucfirst(lc($_[0]))} };
 
-my $VALUES    = { '2'   => 1, '3'    => 1, '4'     => 1, '5'    => 1, '6'     => 1,
-                  '7'   => 1, '8'    => 1, '9'     => 1, '10'   => 1,
-                  'Ace' => 1, 'Jack' => 1, 'Queen' => 1, 'King' => 1, 'Joker' => 1 };
+my $VALUES    = { '2' => 1, '3' => 1, '4' => 1, '5' => 1, '6' => 1,
+                  '7' => 1, '8' => 1, '9' => 1, '10'=> 1,
+                  'A' => 1, 'J' => 1, 'Q' => 1, 'K' => 1, 'Joker' => 1 };
 our $Value    = sub { die "ERROR: Invalid data type 'value' [$_[0]]" unless check_value($_[0]); };
 sub check_value { return exists $VALUES->{ucfirst(lc($_[0]))} };
 
